@@ -254,6 +254,17 @@ class BaseTVAsync(BaseTV):
 
         return self._current_app(current_app_response)
 
+    async def get_hdmi_input(self):
+        """Get the HDMI input from the output of :py:const:`androidtv.constants.CMD_HDMI_INPUT`.
+
+        Returns
+        -------
+        str, None
+            The HDMI input, or ``None`` if it could not be determined
+
+        """
+        return self._get_hdmi_input(await self._adb.shell(constants.CMD_HDMI_INPUT))
+
     async def is_volume_muted(self):
         """Whether or not the volume is muted.
 
@@ -403,7 +414,7 @@ class BaseTVAsync(BaseTV):
             The ID of the app that will be launched
 
         """
-        await self._adb.shell(constants.CMD_LAUNCH_APP.format(app))
+        await self._adb.shell(constants.CMD_LAUNCH_APP.format(app) if not self._is_google_tv else constants.CMD_LAUNCH_APP_GOOGLE_TV.format(app))
 
     async def stop_app(self, app):
         """Stop an app.
